pub struct Simulation {
pub app: App,
pub entity: Entity,
pub world: Arc<RwLock<World>>,
}Expand description
Simulate the Minecraft world to see if certain movements would be possible.
Fields
app: Appentity: Entityworld: Arc<RwLock<World>>Implementations
Sourceimpl Simulation
impl Simulation
pub fn new(chunks: ChunkStorage, player: SimulatedPlayerBundle) -> Self
Sourcepub fn reset(&mut self, player: SimulatedPlayerBundle)
pub fn reset(&mut self, player: SimulatedPlayerBundle)
Despawn the old simulated player and create a new one.
This is cheaper than creating a new Simulation from scratch.
pub fn tick(&mut self)
pub fn component<T: Component + Clone>(&self) -> T
pub fn get_component<T: Component + Clone>(&self) -> Option<T>
pub fn position(&self) -> Vec3
pub fn physics(&self) -> Physics
pub fn is_mining(&self) -> bool